@@ -29,8 +29,12 @@ public:
     explicit GravatarCacheTest(QObject *parent = nullptr);
     ~GravatarCacheTest();
 private Q_SLOTS:
+    void initTestCase();
     void shouldHaveDefaultValue();
     void shouldChangeCacheValue();
+    void testLookup();
+    void testMissing();
+    void testMissing_data();
 };
 
 #endif // GRAVATARCACHETEST_H
